diff mbox series

[v1] pcrypt_aead01: Should be related to CVE-2017-18075

Message ID 20230225003444.2368729-1-edliaw@google.com
State Accepted
Headers show
Series [v1] pcrypt_aead01: Should be related to CVE-2017-18075 | expand

Commit Message

Edward Liaw Feb. 25, 2023, 12:34 a.m. UTC
Fix the association with the correct CVE.

CVE-2017-18075: pcrypt mishandles freeing instances.
CVE-2017-5754: Meltdown.

Signed-off-by: Edward Liaw <edliaw@google.com>
---
 testcases/kernel/crypto/pcrypt_aead01.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

Comments

Li Wang Feb. 25, 2023, 8:04 a.m. UTC | #1
Good catch, merged!
diff mbox series

Patch

diff --git a/testcases/kernel/crypto/pcrypt_aead01.c b/testcases/kernel/crypto/pcrypt_aead01.c
index 5eefee4cb..3b4f5d8d1 100644
--- a/testcases/kernel/crypto/pcrypt_aead01.c
+++ b/testcases/kernel/crypto/pcrypt_aead01.c
@@ -7,7 +7,7 @@ 
  * Originally found by syzkaller:
  * https://groups.google.com/forum/#!topic/syzkaller-bugs/NKn_ivoPOpk
  *
  * Test for CVE-2017-5754 - pcrypt mishandles freeing instances.
  *
  * The test works by adding and then removing pcrypt-AEAD instances.
  * See commit d76c68109f37 crypto: pcrypt - fix freeing pcrypt instances.
@@ -78,7 +78,7 @@  static struct tst_test test = {
 	.max_runtime = 300,
 	.tags = (const struct tst_tag[]) {
 		{"linux-git", "d76c68109f37"},
-		{"CVE", "2017-5754"},
+		{"CVE", "2017-18075"},
 		{}
 	}
 };
@@ -7,7 +7,7 @@ 
  * https://groups.google.com/forum/#!topic/syzkaller-bugs/NKn_ivoPOpk
  *
- * Test for CVE-2017-5754 - pcrypt mishandles freeing instances.
+ * Test for CVE-2017-18075 - pcrypt mishandles freeing instances.
  *
  * The test works by adding and then removing pcrypt-AEAD instances.